==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ReorderSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReorderSpecFluent<A extends ReorderSpecFluent<A>> extends BaseFluent<A>{
  public ReorderSpecFluent() {
  }
  public ReorderSpecFluent(ReorderSpec instance) {
    instance = (instance != null ? instance : new ReorderSpec());

    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withGap(instance.getGap());
      this.withReorder(instance.getReorder());
      this.withCorrelation(instance.getCorrelation());
      this.withGap(instance.getGap());
      this.withReorder(instance.getReorder());
    }
  }
  private String correlation;
  private Integer gap;
  private String reorder;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  public Integer getGap() {
    return this.gap;
  }
  public A withGap(Integer gap) {
    this.gap=gap; return (A) this;
  }
  public boolean hasGap() {
    return this.gap != null;
  }
  public String getReorder() {
    return this.reorder;
  }
  public A withReorder(String reorder) {
    this.reorder=reorder; return (A) this;
  }
  public boolean hasReorder() {
    return this.reorder != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReorderSpecFluent that = (ReorderSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;

    if (!java.util.Objects.equals(gap, that.gap)) return false;

    if (!java.util.Objects.equals(reorder, that.reorder)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  gap,  reorder,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (gap != null) { sb.append("gap:"); sb.append(gap + ","); }
    if (reorder != null) { sb.append("reorder:"); sb.append(reorder); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ReorderSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ReorderSpecFluent<A extends ReorderSpecFluent<A>> extends BaseFluent<A>{
  public ReorderSpecFluent() {
  }
  
  public ReorderSpecFluent(ReorderSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private Integer gap;
  private String reorder;
  
  protected void copyInstance(ReorderSpec instance) {
    instance = (instance != null ? instance : new ReorderSpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withGap(instance.getGap());
        this.withReorder(instance.getReorder());
        this.withCorrelation(instance.getCorrelation());
        this.withGap(instance.getGap());
        this.withReorder(instance.getReorder());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public Integer getGap() {
    return this.gap;
  }
  
  public A withGap(Integer gap) {
    this.gap=gap; return (A) this;
  }
  
  public boolean hasGap() {
    return this.gap != null;
  }
  
  public String getReorder() {
    return this.reorder;
  }
  
  public A withReorder(String reorder) {
    this.reorder=reorder; return (A) this;
  }
  
  public boolean hasReorder() {
    return this.reorder != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReorderSpecFluent that = (ReorderSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(gap, that.gap)) return false;
  
    if (!java.util.Objects.equals(reorder, that.reorder)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  gap,  reorder,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (gap != null) { sb.append("gap:"); sb.append(gap + ","); }
    if (reorder != null) { sb.append("reorder:"); sb.append(reorder); }
    sb.append("}");
    return sb.toString();
  }
  

}
